@@ -5,7 +5,7 @@ set -euxo pipefail
 if [[ "${target_platform}" == osx-* ]]; then
   export LDFLAGS="${LDFLAGS} -framework IOKit"
 else
-  export LDFLAGS="${LDFLAGS} -lpthread"
+  export LDFLAGS="${LDFLAGS} -lpthread -labsl_synchronization"
 fi
 
 # Generate toolchain and set necessary environment variables
@@ -18,8 +18,10 @@ fi
 # For debugging purposes, you can add
 # --logging=6 --subcommands --verbose_failures
 # This is though too much log output for Travis CI.
+export LIBPROTOBUF_VERSION=$(conda list -p $PREFIX libprotobuf | grep -v '^#' | tr -s ' ' | cut -f 2 -d ' ')
 export BAZEL_BUILD_OPTS="--crosstool_top=//bazel_toolchain:toolchain --define=PROTOBUF_INCLUDE_PATH=${PREFIX}/include --cpu=${TARGET_CPU}"
 export EXTRA_BAZEL_ARGS="--host_javabase=@local_jdk//:jdk"
+sed -ie "s:LIBPROTOBUF_VERSION:${LIBPROTOBUF_VERSION}:" WORKSPACE
 sed -ie "s:\${INSTALL_NAME_TOOL}:${INSTALL_NAME_TOOL:-install_name_tool}:" src/BUILD
 sed -ie "s:\${PREFIX}:${PREFIX}:" src/BUILD
 sed -ie "s:\${BUILD_PREFIX}:${BUILD_PREFIX}:" third_party/grpc/BUILD
